==================================
 Information About Older Releases
==================================

.. toctree::
   :caption: Release announcements
   :maxdepth: 2

   whatsnew_1_5
   whatsnew_1_4
   whatsnew_1_3
   whatsnew_1_2
   whatsnew_1_1
   whatsnew_1_0

.. toctree::
   :caption: Older change logs, without context.
   :maxdepth: 2

   changelog_1_5
   changelog_1_4
   changelog_1_3
   changelog_1_2
   changelog_1_1
   changelog_1_0
   changelog_pre
